Class: Google::Cloud::Vision::V1::Feature
- Inherits:
-
Object
- Object
- Google::Cloud::Vision::V1::Feature
- Defined in:
- lib/google/cloud/vision/v1/doc/google/cloud/vision/v1/image_annotator.rb
Overview
Users describe the type of Google Cloud Vision API tasks to perform over images by using Features. Each Feature indicates a type of image detection task to perform. Features encode the Cloud Vision API vertical to operate on and the number of top-scoring results to return.
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Maximum number of results of this type.
-
#type ⇒ Google::Cloud::Vision::V1::Feature::Type
The feature type.
Instance Attribute Details
#max_results ⇒ Integer
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/google/cloud/vision/v1/doc/google/cloud/vision/v1/image_annotator.rb', line 29 class Feature # Type of image feature. module Type # Unspecified feature type. TYPE_UNSPECIFIED = 0 # Run face detection. FACE_DETECTION = 1 # Run landmark detection. LANDMARK_DETECTION = 2 # Run logo detection. LOGO_DETECTION = 3 # Run label detection. LABEL_DETECTION = 4 # Run OCR. TEXT_DETECTION = 5 # Run dense text document OCR. Takes precedence when both # DOCUMENT_TEXT_DETECTION and TEXT_DETECTION are present. DOCUMENT_TEXT_DETECTION = 11 # Run computer vision models to compute image safe-search properties. SAFE_SEARCH_DETECTION = 6 # Compute a set of image properties, such as the image's dominant colors. IMAGE_PROPERTIES = 7 # Run crop hints. CROP_HINTS = 9 # Run web detection. WEB_DETECTION = 10 end end |
#type ⇒ Google::Cloud::Vision::V1::Feature::Type
29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/google/cloud/vision/v1/doc/google/cloud/vision/v1/image_annotator.rb', line 29 class Feature # Type of image feature. module Type # Unspecified feature type. TYPE_UNSPECIFIED = 0 # Run face detection. FACE_DETECTION = 1 # Run landmark detection. LANDMARK_DETECTION = 2 # Run logo detection. LOGO_DETECTION = 3 # Run label detection. LABEL_DETECTION = 4 # Run OCR. TEXT_DETECTION = 5 # Run dense text document OCR. Takes precedence when both # DOCUMENT_TEXT_DETECTION and TEXT_DETECTION are present. DOCUMENT_TEXT_DETECTION = 11 # Run computer vision models to compute image safe-search properties. SAFE_SEARCH_DETECTION = 6 # Compute a set of image properties, such as the image's dominant colors. IMAGE_PROPERTIES = 7 # Run crop hints. CROP_HINTS = 9 # Run web detection. WEB_DETECTION = 10 end end |