Class: Google::Cloud::Vision::V1::Symbol
- Inherits:
-
Object
- Object
- Google::Cloud::Vision::V1::Symbol
- Defined in:
- lib/google/cloud/vision/v1/doc/google/cloud/vision/v1/text_annotation.rb
Overview
A single symbol representation.
Instance Attribute Summary collapse
-
#bounding_box ⇒ Google::Cloud::Vision::V1::BoundingPoly
The bounding box for the symbol.
-
#property ⇒ Google::Cloud::Vision::V1::TextAnnotation::TextProperty
Additional information detected for the symbol.
-
#text ⇒ String
The actual UTF-8 representation of the symbol.
Instance Attribute Details
#bounding_box ⇒ Google::Cloud::Vision::V1::BoundingPoly
Returns The bounding box for the symbol. The vertices are in the order of top-left, top-right, bottom-right, bottom-left. When a rotation of the bounding box is detected the rotation is represented as around the top-left corner as defined when the text is read in the 'natural' orientation. For example:
* when the text is horizontal it might look like:
0----1
| |
3----2
* when it's rotated 180 degrees around the top-left corner it becomes:
2----3
| |
1----0
and the vertice order will still be (0, 1, 2, 3).
227 |
# File 'lib/google/cloud/vision/v1/doc/google/cloud/vision/v1/text_annotation.rb', line 227 class Symbol; end |
#property ⇒ Google::Cloud::Vision::V1::TextAnnotation::TextProperty
Returns Additional information detected for the symbol.
227 |
# File 'lib/google/cloud/vision/v1/doc/google/cloud/vision/v1/text_annotation.rb', line 227 class Symbol; end |
#text ⇒ String
Returns The actual UTF-8 representation of the symbol.
227 |
# File 'lib/google/cloud/vision/v1/doc/google/cloud/vision/v1/text_annotation.rb', line 227 class Symbol; end |