Class: Google::Cloud::Vision::V1::Word

Inherits:
Object
  • Object
show all
Defined in:
lib/google/cloud/vision/v1/doc/google/cloud/vision/v1/text_annotation.rb

Overview

A word representation.

Instance Attribute Summary collapse

Instance Attribute Details

#bounding_boxGoogle::Cloud::Vision::V1::BoundingPoly

Returns The bounding box for the word. The vertices are in the order of top-left, top-right, bottom-right, bottom-left. When a rotation of the bounding box is detected the rotation is represented as around the top-left corner as defined when the text is read in the 'natural' orientation. For example:

* when the text is horizontal it might look like:
 0----1
 |    |
 3----2
* when it's rotated 180 degrees around the top-left corner it becomes:
 2----3
 |    |
 1----0
and the vertice order will still be (0, 1, 2, 3).

Returns:

  • The bounding box for the word. The vertices are in the order of top-left, top-right, bottom-right, bottom-left. When a rotation of the bounding box is detected the rotation is represented as around the top-left corner as defined when the text is read in the 'natural' orientation. For example:

    * when the text is horizontal it might look like:
     0----1
     |    |
     3----2
    * when it's rotated 180 degrees around the top-left corner it becomes:
     2----3
     |    |
     1----0
    and the vertice order will still be (0, 1, 2, 3).


201
# File 'lib/google/cloud/vision/v1/doc/google/cloud/vision/v1/text_annotation.rb', line 201

class Word; end

#propertyGoogle::Cloud::Vision::V1::TextAnnotation::TextProperty

Returns Additional information detected for the word.

Returns:

  • Additional information detected for the word.



201
# File 'lib/google/cloud/vision/v1/doc/google/cloud/vision/v1/text_annotation.rb', line 201

class Word; end

#symbolsArray<Google::Cloud::Vision::V1::Symbol>

Returns List of symbols in the word. The order of the symbols follows the natural reading order.

Returns:

  • List of symbols in the word. The order of the symbols follows the natural reading order.



201
# File 'lib/google/cloud/vision/v1/doc/google/cloud/vision/v1/text_annotation.rb', line 201

class Word; end