Module: Google::Cloud::Vision
- Defined in:
- lib/google/cloud/vision.rb,
lib/google/cloud/vision/version.rb
Constant Summary collapse
- VERSION =
"2.2.0"
Class Method Summary collapse
-
.configure {|::Google::Cloud.configure.vision| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-vision library.
-
.image_annotator(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for ImageAnnotator.
-
.image_annotator_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the ImageAnnotator service is supported by the current client.
-
.product_search(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for ProductSearch.
-
.product_search_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the ProductSearch service is supported by the current client.
Class Method Details
.configure {|::Google::Cloud.configure.vision| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-vision library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:jitter(type:Numeric) - The jitter in seconds. Default: 1.0.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
234 235 236 237 238 |
# File 'lib/google/cloud/vision.rb', line 234 def self.configure yield ::Google::Cloud.configure.vision if block_given? ::Google::Cloud.configure.vision end |
.image_annotator(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for ImageAnnotator.
By default, this returns an instance of
Google::Cloud::Vision::V1::ImageAnnotator::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the ImageAnnotator service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the ImageAnnotator service. You can determine whether the method will succeed by calling image_annotator_available?.
About ImageAnnotator
Service that performs Google Cloud Vision API detection tasks over client images, such as face, landmark, logo, label, and text detection. The ImageAnnotator service returns detected entities from the images.
162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/google/cloud/vision.rb', line 162 def self.image_annotator version: :v1, transport: :grpc, &block require "google/cloud/vision/#{version.to_s.downcase}" package_name = Google::Cloud::Vision .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Vision.const_get(package_name).const_get(:ImageAnnotator) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.image_annotator_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the ImageAnnotator service is supported by the current client. If true, you can retrieve a client object by calling image_annotator. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the ImageAnnotator service, or if the versioned client gem needs an update to support the ImageAnnotator service.
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/google/cloud/vision.rb', line 186 def self.image_annotator_available? version: :v1, transport: :grpc require "google/cloud/vision/#{version.to_s.downcase}" package_name = Google::Cloud::Vision .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::Vision.const_get package_name return false unless service_module.const_defined? :ImageAnnotator service_module = service_module.const_get :ImageAnnotator if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.product_search(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for ProductSearch.
By default, this returns an instance of
Google::Cloud::Vision::V1::ProductSearch::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the ProductSearch service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the ProductSearch service. You can determine whether the method will succeed by calling product_search_available?.
About ProductSearch
Manages Products and ProductSets of reference images for use in product search. It uses the following resource model:
- The API has a collection of ProductSet
resources, named
projects/*/locations/*/productSets/*, which acts as a way to put different products into groups to limit identification.
In parallel,
The API has a collection of Product resources, named
projects/*/locations/*/products/*Each Product has a collection of ReferenceImage resources, named
projects/*/locations/*/products/*/referenceImages/*
90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/google/cloud/vision.rb', line 90 def self.product_search version: :v1, transport: :grpc, &block require "google/cloud/vision/#{version.to_s.downcase}" package_name = Google::Cloud::Vision .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Vision.const_get(package_name).const_get(:ProductSearch) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.product_search_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the ProductSearch service is supported by the current client. If true, you can retrieve a client object by calling product_search. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the ProductSearch service, or if the versioned client gem needs an update to support the ProductSearch service.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/google/cloud/vision.rb', line 114 def self.product_search_available? version: :v1, transport: :grpc require "google/cloud/vision/#{version.to_s.downcase}" package_name = Google::Cloud::Vision .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::Vision.const_get package_name return false unless service_module.const_defined? :ProductSearch service_module = service_module.const_get :ProductSearch if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |